.. _howtos:

*************
How-To Guides
*************

We have prepared a list of brief recipes for busy researchers who want to
perform specific tasks using ``zenopy`` without gaining a deeper understanding
of how the software works on the lower levels.

.. toctree::
    :maxdepth: 2
    :titlesonly:
    
    client/index
    records/index
    depositions/index
    deposition_actions/index
    deposition_files/index